@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import io
 import json
 import os
+import socket
 import tempfile
 import time
 from unittest import TestCase
@@ -321,3 +322,63 @@ class HttpEntryTestCase(HttpTestCase):
         files = {"content": file_obj}
         r = requests.post(url, files=files, data={}, verify=False)
         self.assertEqual(r.status_code, 201)
+
+    @mocketize
+    def test_raise_exception(self):
+        url = "http://github.com/fluidicon.png"
+        Entry.single_register(Entry.GET, url, exception=socket.error())
+        with self.assertRaises(requests.exceptions.ConnectionError):
+            requests.get(url)
+
+    @mocketize
+    def test_sockets(self):
+        """
+        https://github.com/mindflayer/python-mocket/issues/111
+        https://gist.github.com/amotl/015ef6b336db55128798d7f1a9a67dea
+        """
+
+        # Define HTTP conversation.
+        url = "http://127.0.0.1:8080/api/data"
+        Entry.single_register(Entry.POST, url)
+
+        # Define HTTP url segments and data.
+        host = "127.0.0.1"
+        port = 8080
+        method = "POST"
+        path = "/api/data"
+        data = json.dumps({"hello": "world"})
+
+        # Invoke HTTP request.
+        address = socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM)[0]
+        sock = socket.socket(address[0], address[1], address[2])
+
+        sock.connect(address[-1])
+        sock.write("%s %s HTTP/1.0\r\n" % (method, path))
+        sock.write("Host: %s\r\n" % host)
+        sock.write("Content-Type: application/json\r\n")
+        sock.write("Content-Length: %d\r\n" % len(data))
+        sock.write("Connection: close\r\n\r\n")
+        sock.write(data)
+        sock.close()
+
+        # Proof that worked.
+        self.assertEqual(Mocket.last_request().body, '{"hello": "world"}')
+
+    @mocketize
+    def test_fail_because_entry_not_served(self):
+        url = "http://github.com/fluidicon.png"
+        Entry.single_register(Entry.GET, url)
+        Entry.single_register(Entry.GET, "http://github.com/fluidicon.jpg")
+        requests.get(url)
+        with self.assertRaises(AssertionError):
+            Mocket.assert_fail_if_entries_not_served()
+
+    @mocketize
+    def test_does_not_fail_because_all_entries_are_served(self):
+        url = "http://github.com/fluidicon.png"
+        second_url = "http://github.com/fluidicon.jpg"
+        Entry.single_register(Entry.GET, url)
+        Entry.single_register(Entry.GET, second_url)
+        requests.get(url)
+        requests.get(second_url)
+        Mocket.assert_fail_if_entries_not_served()
